@@ -24,7 +24,9 @@ from kombu import exceptions
 from .log import get_logger
 from .transport import get_transport_cls, supports_librabbitmq
 from .utils import cached_property, retry_over_time, shufflecycle
-from .utils.compat import OrderedDict, LifoQueue as _LifoQueue, next
+from .utils.compat import (
+    OrderedDict, LifoQueue as _LifoQueue, next, get_errno,
+)
 from .utils.functional import promise
 from .utils.url import parse_url
 
@@ -290,7 +292,7 @@ class Connection(object):
             self.more_to_read = False
             return False
         except socket.error, exc:
-            if exc.errno in (errno.EAGAIN, errno.EINTR):
+            if get_errno(exc) in (errno.EAGAIN, errno.EINTR):
                 self.more_to_read = False
                 return False
             raise
